
******
Vector
******

The Vector class in RedisVL is a container that encapsulates a numerical vector, it's datatype, corresponding index field name, and optional importance weight. It is used when constructing multi-vector queries using the MultiVectorQuery class.


Vector
===========

.. currentmodule:: redisvl.query


.. autoclass:: Vector
   :members:
   :exclude-members: 
